<html>
<head>
<meta http-equiv="refresh" content="0;url=classes.html">
</head>
<body>
<?cs include:"analytics.cs" ?>
</body>
</html>